.. pynbody tutorials main index

.. _tutorials:

Pynbody Tutorials
=================

Here you will find tutorials that illustrate the use of pynbody. The
:ref:`walkthroughs` demonstrate pynbody functionality through an
interactive session in the ipython shell that you can follow along
using either one of the outputs from the bundled test-data or one of
your own simulations. To complement the walkthroughs, we also provide
a few `IPython notebooks
<https://github.com/pynbody/pynbody/tree/master/examples/notebooks>`_. The
:ref:`cookbook` tutorials are more goal-oriented: they provide a
script that can be used with only minor modifications to immediately
produce a result (i.e. make an image). They also include, however, a
somewhat more involved discussion of more advanced options and common
pitfalls. Finally, the :ref:`advanced_topics` section is meant to
provide a more in-depth look at the inner-workings of the code.

.. _walkthroughs:

Walkthroughs
------------

.. toctree::
   :maxdepth: 1

   A first look at your data with pynbody <snapshot_manipulation>
   Basic data access <data_access>
   Subviews and Filters <filters>
   Tracing particles across different snapshots <bridge>

.. _cookbook:

Cookbook/Recipes
----------------

.. toctree::
   :maxdepth: 1

   Profiles <profile>
   Rotation curves <rotation_curve>
   Making Pictures <pictures>
   Group finding <halos>
   Halo mass Function <hmf>


.. _advanced_topics:

Advanced topics
---------------

These tutorials are likely to be of interest only in special cases.

.. toctree::
   :maxdepth: 1

   Performance issues <performance>
   Configuring Pynbody <configuration>
   Understanding threading <threads>
